# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class EventsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_events(self,
                           network_id,
                           product_type=None,
                           included_event_types=None,
                           excluded_event_types=None,
                           device_mac=None,
                           device_serial=None,
                           device_name=None,
                           client_ip=None,
                           client_mac=None,
                           client_name=None,
                           sm_device_mac=None,
                           sm_device_name=None,
                           per_page=None,
                           starting_after=None,
                           ending_before=None):
        """Does a GET request to /networks/{networkId}/events.

        List the events for the network

        Args:
            network_id (string): TODO: type description here. Example: 
            product_type (string, optional): The product type to fetch events
                for. This parameter is required for networks with multiple
                device types. Valid types are wireless, appliance, switch,
                systemsManager, and camera
            included_event_types (list of string, optional): A list of event
                types. The returned events will be filtered to only include
                events with these types.
            excluded_event_types (list of string, optional): A list of event
                types. The returned events will be filtered to exclude events
                with these types.
            device_mac (string, optional): The MAC address of the Meraki
                device which the list of events will be filtered with
            device_serial (string, optional): The serial of the Meraki device
                which the list of events will be filtered with
            device_name (string, optional): The name of the Meraki device
                which the list of events will be filtered with
            client_ip (string, optional): The IP of the client which the list
                of events will be filtered with. Only supported for
                track-by-IP networks.
            client_mac (string, optional): The MAC address of the client which
                the list of events will be filtered with. Only supported for
                track-by-MAC networks.
            client_name (string, optional): The name, or partial name, of the
                client which the list of events will be filtered with
            sm_device_mac (string, optional): The MAC address of the Systems
                Manager device which the list of events will be filtered with
            sm_device_name (string, optional): The name of the Systems Manager
                device which the list of events will be filtered with
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 10.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/events'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'productType': product_type,
            'includedEventTypes': included_event_types,
            'excludedEventTypes': excluded_event_types,
            'deviceMac': device_mac,
            'deviceSerial': device_serial,
            'deviceName': device_name,
            'clientIp': client_ip,
            'clientMac': client_mac,
            'clientName': client_name,
            'smDeviceMac': sm_device_mac,
            'smDeviceName': sm_device_name,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_events_event_types(self,
                                       network_id):
        """Does a GET request to /networks/{networkId}/events/eventTypes.

        List the event type to human-readable description

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/events/eventTypes'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.action

class CreateOrganizationActionBatch(object):

    """Implementation of the 'createOrganizationActionBatch' model.

    TODO: type model description here.

    Attributes:
        confirmed (bool): Set to true for immediate execution. Set to false if
            the action should be previewed before executing. This property
            cannot be unset once it is true. Defaults to false.
        synchronous (bool): Set to true to force the batch to run synchronous.
            There can be at most 20 actions in synchronous batch. Defaults to
            false.
        actions (list of Action): A set of changes to make as part of this
            action (<a
            href='https://developer.cisco.com/meraki/api/#/rest/guides/action-b
            atches/'>more details</a>)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "actions":'actions',
        "confirmed":'confirmed',
        "synchronous":'synchronous'
    }

    def __init__(self,
                 actions=None,
                 confirmed=None,
                 synchronous=None):
        """Constructor for the CreateOrganizationActionBatch class"""

        # Initialize members of the class
        self.confirmed = confirmed
        self.synchronous = synchronous
        self.actions = actions


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        actions = None
        if dictionary.get('actions') != None:
            actions = list()
            for structure in dictionary.get('actions'):
                actions.append(test_meraki.models.action.Action.from_dictionary(structure))
        confirmed = dictionary.get('confirmed')
        synchronous = dictionary.get('synchronous')

        # Return an object of this model
        return cls(actions,
                   confirmed,
                   synchronous)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class UdldEnum(object):

    """Implementation of the 'Udld' enum.

    The action to take when Unidirectional Link is detected (Alert only,
    Enforce). Default configuration is Alert only.

    Attributes:
        ENUM_ALERT ONLY: TODO: type description here.
        ENFORCE: TODO: type description here.

    """

    ENUM_ALERT_ONLY = 'Alert only'

    ENFORCE = 'Enforce'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Type9Enum(object):

    """Implementation of the 'Type9' enum.

    The type for the DHCP option. One of: 'text', 'ip', 'hex' or 'integer'

    Attributes:
        TEXT: TODO: type description here.
        IP: TODO: type description here.
        HEX: TODO: type description here.
        INTEGER: TODO: type description here.

    """

    TEXT = 'text'

    IP = 'ip'

    HEX = 'hex'

    INTEGER = 'integer'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkWarmSpareSettings(object):

    """Implementation of the 'updateNetworkWarmSpareSettings' model.

    TODO: type model description here.

    Attributes:
        enabled (bool): Enable warm spare
        spare_serial (string): Serial number of the warm spare appliance
        uplink_mode (string): Uplink mode, either virtual or public
        virtual_ip_1 (string): The WAN 1 shared IP
        virtual_ip_2 (string): The WAN 2 shared IP

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "enabled":'enabled',
        "spare_serial":'spareSerial',
        "uplink_mode":'uplinkMode',
        "virtual_ip_1":'virtualIp1',
        "virtual_ip_2":'virtualIp2'
    }

    def __init__(self,
                 enabled=None,
                 spare_serial=None,
                 uplink_mode=None,
                 virtual_ip_1=None,
                 virtual_ip_2=None):
        """Constructor for the UpdateNetworkWarmSpareSettings class"""

        # Initialize members of the class
        self.enabled = enabled
        self.spare_serial = spare_serial
        self.uplink_mode = uplink_mode
        self.virtual_ip_1 = virtual_ip_1
        self.virtual_ip_2 = virtual_ip_2


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        enabled = dictionary.get('enabled')
        spare_serial = dictionary.get('spareSerial')
        uplink_mode = dictionary.get('uplinkMode')
        virtual_ip_1 = dictionary.get('virtualIp1')
        virtual_ip_2 = dictionary.get('virtualIp2')

        # Return an object of this model
        return cls(enabled,
                   spare_serial,
                   uplink_mode,
                   virtual_ip_1,
                   virtual_ip_2)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.allowed_url
import test_meraki.models.allowed_file

class UpdateNetworkSecurityMalwareSettings(object):

    """Implementation of the 'updateNetworkSecurityMalwareSettings' model.

    TODO: type model description here.

    Attributes:
        mode (string): Set mode to 'enabled' to enable malware prevention,
            otherwise 'disabled'
        allowed_urls (list of AllowedUrl): The urls that should be permitted
            by the malware detection engine. If omitted, the current config
            will remain unchanged. This is available only if your network
            supports AMP whitelisting
        allowed_files (list of AllowedFile): The sha256 digests of files that
            should be permitted by the malware detection engine. If omitted,
            the current config will remain unchanged. This is available only
            if your network supports AMP whitelisting

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mode":'mode',
        "allowed_urls":'allowedUrls',
        "allowed_files":'allowedFiles'
    }

    def __init__(self,
                 mode=None,
                 allowed_urls=None,
                 allowed_files=None):
        """Constructor for the UpdateNetworkSecurityMalwareSettings class"""

        # Initialize members of the class
        self.mode = mode
        self.allowed_urls = allowed_urls
        self.allowed_files = allowed_files


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mode = dictionary.get('mode')
        allowed_urls = None
        if dictionary.get('allowedUrls') != None:
            allowed_urls = list()
            for structure in dictionary.get('allowedUrls'):
                allowed_urls.append(test_meraki.models.allowed_url.AllowedUrl.from_dictionary(structure))
        allowed_files = None
        if dictionary.get('allowedFiles') != None:
            allowed_files = list()
            for structure in dictionary.get('allowedFiles'):
                allowed_files.append(test_meraki.models.allowed_file.AllowedFile.from_dictionary(structure))

        # Return an object of this model
        return cls(mode,
                   allowed_urls,
                   allowed_files)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RadiusFailoverPolicyEnum(object):

    """Implementation of the 'RadiusFailoverPolicy' enum.

    This policy determines how authentication requests should be handled in
    the event that all of the configured RADIUS servers are unreachable ('Deny
    access' or 'Allow access')

    Attributes:
        ENUM_DENY ACCESS: TODO: type description here.
        ENUM_ALLOW ACCESS: TODO: type description here.

    """

    ENUM_DENY_ACCESS = 'Deny access'

    ENUM_ALLOW_ACCESS = 'Allow access'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class OrgAccessEnum(object):

    """Implementation of the 'OrgAccess' enum.

    The privilege of the dashboard administrator on the organization. Can be
    one of 'full', 'read-only', 'enterprise' or 'none'

    Attributes:
        FULL: TODO: type description here.
        READONLY: TODO: type description here.
        ENTERPRISE: TODO: type description here.
        NONE: TODO: type description here.

    """

    FULL = 'full'

    READONLY = 'read-only'

    ENTERPRISE = 'enterprise'

    NONE = 'none'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkAppliancePort(object):

    """Implementation of the 'updateNetworkAppliancePort' model.

    TODO: type model description here.

    Attributes:
        enabled (bool): The status of the port
        drop_untagged_traffic (bool): Trunk port can Drop all Untagged
            traffic. When true, no VLAN is required. Access ports cannot have
            dropUntaggedTraffic set to true.
        mtype (string): The type of the port: 'access' or 'trunk'.
        vlan (int): Native VLAN when the port is in Trunk mode. Access VLAN
            when the port is in Access mode.
        allowed_vlans (string): Comma-delimited list of the VLAN ID's allowed
            on the port, or 'all' to permit all VLAN's on the port.
        access_policy (string): The name of the policy. Only applicable to
            Access ports. Valid values are: 'open', '8021x-radius',
            'mac-radius', 'hybris-radius' for MX64 or Z3 or any MX supporting
            the per port authentication feature. Otherwise, 'open' is the only
            valid value and 'open' is the default value if the field is
            missing.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "enabled":'enabled',
        "drop_untagged_traffic":'dropUntaggedTraffic',
        "mtype":'type',
        "vlan":'vlan',
        "allowed_vlans":'allowedVlans',
        "access_policy":'accessPolicy'
    }

    def __init__(self,
                 enabled=None,
                 drop_untagged_traffic=None,
                 mtype=None,
                 vlan=None,
                 allowed_vlans=None,
                 access_policy=None):
        """Constructor for the UpdateNetworkAppliancePort class"""

        # Initialize members of the class
        self.enabled = enabled
        self.drop_untagged_traffic = drop_untagged_traffic
        self.mtype = mtype
        self.vlan = vlan
        self.allowed_vlans = allowed_vlans
        self.access_policy = access_policy


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        enabled = dictionary.get('enabled')
        drop_untagged_traffic = dictionary.get('dropUntaggedTraffic')
        mtype = dictionary.get('type')
        vlan = dictionary.get('vlan')
        allowed_vlans = dictionary.get('allowedVlans')
        access_policy = dictionary.get('accessPolicy')

        # Return an object of this model
        return cls(enabled,
                   drop_untagged_traffic,
                   mtype,
                   vlan,
                   allowed_vlans,
                   access_policy)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSmAppPolaris(object):

    """Implementation of the 'updateNetworkSmAppPolaris' model.

    TODO: type model description here.

    Attributes:
        scope (string): optional: The scope (one of all, none, automatic,
            withAny, withAll, withoutAny, or withoutAll) and a set of tags of
            the devices to be assigned
        prevent_auto_install (bool): optional: Whether or not SM should
            auto-install this app (one of true or false)
        uses_vpp (bool): optional: Whether or not the app should use VPP by
            device assignment (one of true or false)

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "scope":'scope',
        "prevent_auto_install":'preventAutoInstall',
        "uses_vpp":'usesVPP'
    }

    def __init__(self,
                 scope=None,
                 prevent_auto_install=None,
                 uses_vpp=None):
        """Constructor for the UpdateNetworkSmAppPolaris class"""

        # Initialize members of the class
        self.scope = scope
        self.prevent_auto_install = prevent_auto_install
        self.uses_vpp = uses_vpp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        scope = dictionary.get('scope')
        prevent_auto_install = dictionary.get('preventAutoInstall')
        uses_vpp = dictionary.get('usesVPP')

        # Return an object of this model
        return cls(scope,
                   prevent_auto_install,
                   uses_vpp)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class ObjectTypeEnum(object):

    """Implementation of the 'objectType' enum.

    TODO: type enum description here.

    Attributes:
        PERSON: TODO: type description here.
        VEHICLE: TODO: type description here.

    """

    PERSON = 'person'

    VEHICLE = 'vehicle'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class GenerateNetworkCameraSnapshot(object):

    """Implementation of the 'generateNetworkCameraSnapshot' model.

    TODO: type model description here.

    Attributes:
        timestamp (string): [optional] The snapshot will be taken from this
            time on the camera. The timestamp is expected to be in ISO 8601
            format. If no timestamp is specified, we will assume current
            time.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "timestamp":'timestamp'
    }

    def __init__(self,
                 timestamp=None):
        """Constructor for the GenerateNetworkCameraSnapshot class"""

        # Initialize members of the class
        self.timestamp = timestamp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        timestamp = dictionary.get('timestamp')

        # Return an object of this model
        return cls(timestamp)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.radius_server
import test_meraki.models.radius_accounting_server
import test_meraki.models.ap_tags_and_vlan_id

class UpdateNetworkSsid(object):

    """Implementation of the 'updateNetworkSsid' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the SSID
        enabled (bool): Whether or not the SSID is enabled
        auth_mode (AuthModeEnum): The association control method for the SSID
            ('open', 'psk', 'open-with-radius', '8021x-meraki' or
            '8021x-radius')
        enterprise_admin_access (EnterpriseAdminAccessEnum): Whether or not an
            SSID is accessible by 'enterprise' administrators ('access
            disabled' or 'access enabled')
        encryption_mode (EncryptionModeEnum): The psk encryption mode for the
            SSID ('wep' or 'wpa'). This param is only valid if the authMode is
            'psk'
        psk (string): The passkey for the SSID. This param is only valid if
            the authMode is 'psk'
        wpa_encryption_mode (WpaEncryptionModeEnum): The types of WPA
            encryption. ('WPA1 and WPA2' or 'WPA2 only')
        splash_page (SplashPageEnum): The type of splash page for the SSID
            ('None', 'Click-through splash page', 'Billing',
            'Password-protected with Meraki RADIUS', 'Password-protected with
            custom RADIUS', 'Password-protected with Active Directory',
            'Password-protected with LDAP', 'SMS authentication', 'Systems
            Manager Sentry', 'Facebook Wi-Fi', 'Google OAuth' or 'Sponsored
            guest'). This attribute is not supported for template children.
        radius_servers (list of RadiusServer): The RADIUS 802.1x servers to be
            used for authentication. This param is only valid if the authMode
            is 'open-with-radius' or '8021x-radius'
        radius_coa_enabled (bool): If true, Meraki devices will act as a
            RADIUS Dynamic Authorization Server and will respond to RADIUS
            Change-of-Authorization and Disconnect messages sent by the RADIUS
            server.
        radius_failover_policy (RadiusFailoverPolicyEnum): This policy
            determines how authentication requests should be handled in the
            event that all of the configured RADIUS servers are unreachable
            ('Deny access' or 'Allow access')
        radius_load_balancing_policy (RadiusLoadBalancingPolicyEnum): This
            policy determines which RADIUS server will be contacted first in
            an authentication attempt and the ordering of any necessary retry
            attempts ('Strict priority order' or 'Round robin')
        radius_accounting_enabled (bool): Whether or not RADIUS accounting is
            enabled. This param is only valid if the authMode is
            'open-with-radius' or '8021x-radius'
        radius_accounting_servers (list of RadiusAccountingServer): The RADIUS
            accounting 802.1x servers to be used for authentication. This
            param is only valid if the authMode is 'open-with-radius' or
            '8021x-radius' and radiusAccountingEnabled is 'true'
        radius_attribute_for_group_policies (string): Specify the RADIUS
            attribute used to look up group policies ('Filter-Id',
            'Reply-Message', 'Airespace-ACL-Name' or 'Aruba-User-Role').
            Access points must receive this attribute in the RADIUS
            Access-Accept message
        ip_assignment_mode (string): The client IP assignment mode ('NAT
            mode', 'Bridge mode', 'Layer 3 roaming', 'Layer 3 roaming with a
            concentrator' or 'VPN')
        use_vlan_tagging (bool): Whether or not traffic should be directed to
            use specific VLANs. This param is only valid if the
            ipAssignmentMode is 'Bridge mode' or 'Layer 3 roaming'
        concentrator_network_id (string): The concentrator to use when the
            ipAssignmentMode is 'Layer 3 roaming with a concentrator' or
            'VPN'.
        vlan_id (int): The VLAN ID used for VLAN tagging. This param is only
            valid when the ipAssignmentMode is 'Layer 3 roaming with a
            concentrator' or 'VPN'
        default_vlan_id (int): The default VLAN ID used for 'all other APs'.
            This param is only valid when the ipAssignmentMode is 'Bridge
            mode' or 'Layer 3 roaming'
        ap_tags_and_vlan_ids (list of ApTagsAndVlanId): The list of tags and
            VLAN IDs used for VLAN tagging. This param is only valid when the
            ipAssignmentMode is 'Bridge mode' or 'Layer 3 roaming'
        walled_garden_enabled (bool): Allow access to a configurable list of
            IP ranges, which users may access prior to sign-on.
        walled_garden_ranges (string): Specify your walled garden by entering
            space-separated addresses, ranges using CIDR notation, domain
            names, and domain wildcards (e.g. 192.168.1.1/24 192.168.37.10/32
            www.yahoo.com *.google.com). Meraki's splash page is automatically
            included in your walled garden.
        radius_override (bool): If true, the RADIUS response can override VLAN
            tag. This is not valid when ipAssignmentMode is 'NAT mode'.
        min_bitrate (float): The minimum bitrate in Mbps. ('1', '2', '5.5',
            '6', '9', '11', '12', '18', '24', '36', '48' or '54')
        band_selection (string): The client-serving radio frequencies. ('Dual
            band operation', '5 GHz band only' or 'Dual band operation with
            Band Steering')
        per_client_bandwidth_limit_up (int): The upload bandwidth limit in
            Kbps. (0 represents no limit.)
        per_client_bandwidth_limit_down (int): The download bandwidth limit in
            Kbps. (0 represents no limit.)
        lan_isolation_enabled (bool): Boolean indicating whether Layer 2 LAN
            isolation should be enabled or disabled. Only configurable when
            ipAssignmentMode is 'Bridge mode'.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "enabled":'enabled',
        "auth_mode":'authMode',
        "enterprise_admin_access":'enterpriseAdminAccess',
        "encryption_mode":'encryptionMode',
        "psk":'psk',
        "wpa_encryption_mode":'wpaEncryptionMode',
        "splash_page":'splashPage',
        "radius_servers":'radiusServers',
        "radius_coa_enabled":'radiusCoaEnabled',
        "radius_failover_policy":'radiusFailoverPolicy',
        "radius_load_balancing_policy":'radiusLoadBalancingPolicy',
        "radius_accounting_enabled":'radiusAccountingEnabled',
        "radius_accounting_servers":'radiusAccountingServers',
        "radius_attribute_for_group_policies":'radiusAttributeForGroupPolicies',
        "ip_assignment_mode":'ipAssignmentMode',
        "use_vlan_tagging":'useVlanTagging',
        "concentrator_network_id":'concentratorNetworkId',
        "vlan_id":'vlanId',
        "default_vlan_id":'defaultVlanId',
        "ap_tags_and_vlan_ids":'apTagsAndVlanIds',
        "walled_garden_enabled":'walledGardenEnabled',
        "walled_garden_ranges":'walledGardenRanges',
        "radius_override":'radiusOverride',
        "min_bitrate":'minBitrate',
        "band_selection":'bandSelection',
        "per_client_bandwidth_limit_up":'perClientBandwidthLimitUp',
        "per_client_bandwidth_limit_down":'perClientBandwidthLimitDown',
        "lan_isolation_enabled":'lanIsolationEnabled'
    }

    def __init__(self,
                 name=None,
                 enabled=None,
                 auth_mode=None,
                 enterprise_admin_access=None,
                 encryption_mode=None,
                 psk=None,
                 wpa_encryption_mode=None,
                 splash_page=None,
                 radius_servers=None,
                 radius_coa_enabled=None,
                 radius_failover_policy=None,
                 radius_load_balancing_policy=None,
                 radius_accounting_enabled=None,
                 radius_accounting_servers=None,
                 radius_attribute_for_group_policies=None,
                 ip_assignment_mode=None,
                 use_vlan_tagging=None,
                 concentrator_network_id=None,
                 vlan_id=None,
                 default_vlan_id=None,
                 ap_tags_and_vlan_ids=None,
                 walled_garden_enabled=None,
                 walled_garden_ranges=None,
                 radius_override=None,
                 min_bitrate=None,
                 band_selection=None,
                 per_client_bandwidth_limit_up=None,
                 per_client_bandwidth_limit_down=None,
                 lan_isolation_enabled=None):
        """Constructor for the UpdateNetworkSsid class"""

        # Initialize members of the class
        self.name = name
        self.enabled = enabled
        self.auth_mode = auth_mode
        self.enterprise_admin_access = enterprise_admin_access
        self.encryption_mode = encryption_mode
        self.psk = psk
        self.wpa_encryption_mode = wpa_encryption_mode
        self.splash_page = splash_page
        self.radius_servers = radius_servers
        self.radius_coa_enabled = radius_coa_enabled
        self.radius_failover_policy = radius_failover_policy
        self.radius_load_balancing_policy = radius_load_balancing_policy
        self.radius_accounting_enabled = radius_accounting_enabled
        self.radius_accounting_servers = radius_accounting_servers
        self.radius_attribute_for_group_policies = radius_attribute_for_group_policies
        self.ip_assignment_mode = ip_assignment_mode
        self.use_vlan_tagging = use_vlan_tagging
        self.concentrator_network_id = concentrator_network_id
        self.vlan_id = vlan_id
        self.default_vlan_id = default_vlan_id
        self.ap_tags_and_vlan_ids = ap_tags_and_vlan_ids
        self.walled_garden_enabled = walled_garden_enabled
        self.walled_garden_ranges = walled_garden_ranges
        self.radius_override = radius_override
        self.min_bitrate = min_bitrate
        self.band_selection = band_selection
        self.per_client_bandwidth_limit_up = per_client_bandwidth_limit_up
        self.per_client_bandwidth_limit_down = per_client_bandwidth_limit_down
        self.lan_isolation_enabled = lan_isolation_enabled


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        enabled = dictionary.get('enabled')
        auth_mode = dictionary.get('authMode')
        enterprise_admin_access = dictionary.get('enterpriseAdminAccess')
        encryption_mode = dictionary.get('encryptionMode')
        psk = dictionary.get('psk')
        wpa_encryption_mode = dictionary.get('wpaEncryptionMode')
        splash_page = dictionary.get('splashPage')
        radius_servers = None
        if dictionary.get('radiusServers') != None:
            radius_servers = list()
            for structure in dictionary.get('radiusServers'):
                radius_servers.append(test_meraki.models.radius_server.RadiusServer.from_dictionary(structure))
        radius_coa_enabled = dictionary.get('radiusCoaEnabled')
        radius_failover_policy = dictionary.get('radiusFailoverPolicy')
        radius_load_balancing_policy = dictionary.get('radiusLoadBalancingPolicy')
        radius_accounting_enabled = dictionary.get('radiusAccountingEnabled')
        radius_accounting_servers = None
        if dictionary.get('radiusAccountingServers') != None:
            radius_accounting_servers = list()
            for structure in dictionary.get('radiusAccountingServers'):
                radius_accounting_servers.append(test_meraki.models.radius_accounting_server.RadiusAccountingServer.from_dictionary(structure))
        radius_attribute_for_group_policies = dictionary.get('radiusAttributeForGroupPolicies')
        ip_assignment_mode = dictionary.get('ipAssignmentMode')
        use_vlan_tagging = dictionary.get('useVlanTagging')
        concentrator_network_id = dictionary.get('concentratorNetworkId')
        vlan_id = dictionary.get('vlanId')
        default_vlan_id = dictionary.get('defaultVlanId')
        ap_tags_and_vlan_ids = None
        if dictionary.get('apTagsAndVlanIds') != None:
            ap_tags_and_vlan_ids = list()
            for structure in dictionary.get('apTagsAndVlanIds'):
                ap_tags_and_vlan_ids.append(test_meraki.models.ap_tags_and_vlan_id.ApTagsAndVlanId.from_dictionary(structure))
        walled_garden_enabled = dictionary.get('walledGardenEnabled')
        walled_garden_ranges = dictionary.get('walledGardenRanges')
        radius_override = dictionary.get('radiusOverride')
        min_bitrate = dictionary.get('minBitrate')
        band_selection = dictionary.get('bandSelection')
        per_client_bandwidth_limit_up = dictionary.get('perClientBandwidthLimitUp')
        per_client_bandwidth_limit_down = dictionary.get('perClientBandwidthLimitDown')
        lan_isolation_enabled = dictionary.get('lanIsolationEnabled')

        # Return an object of this model
        return cls(name,
                   enabled,
                   auth_mode,
                   enterprise_admin_access,
                   encryption_mode,
                   psk,
                   wpa_encryption_mode,
                   splash_page,
                   radius_servers,
                   radius_coa_enabled,
                   radius_failover_policy,
                   radius_load_balancing_policy,
                   radius_accounting_enabled,
                   radius_accounting_servers,
                   radius_attribute_for_group_policies,
                   ip_assignment_mode,
                   use_vlan_tagging,
                   concentrator_network_id,
                   vlan_id,
                   default_vlan_id,
                   ap_tags_and_vlan_ids,
                   walled_garden_enabled,
                   walled_garden_ranges,
                   radius_override,
                   min_bitrate,
                   band_selection,
                   per_client_bandwidth_limit_up,
                   per_client_bandwidth_limit_down,
                   lan_isolation_enabled)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class RadiusLoadBalancingPolicyEnum(object):

    """Implementation of the 'RadiusLoadBalancingPolicy' enum.

    This policy determines which RADIUS server will be contacted first in an
    authentication attempt and the ordering of any necessary retry attempts
    ('Strict priority order' or 'Round robin')

    Attributes:
        ENUM_STRICT PRIORITY ORDER: TODO: type description here.
        ENUM_ROUND ROBIN: TODO: type description here.

    """

    ENUM_STRICT_PRIORITY_ORDER = 'Strict priority order'

    ENUM_ROUND_ROBIN = 'Round robin'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.provider_configuration

class AddNetworkSmProfileUmbrella(object):

    """Implementation of the 'addNetworkSmProfileUmbrella' model.

    TODO: type model description here.

    Attributes:
        app_bundle_identifier (string): The bundle ID of the application,
            defaults to com.cisco.ciscosecurity.app
        provider_bundle_identifier (string): The bundle ID of the provider,
            defaults to com.cisco.ciscosecurity.app.CiscoUmbrella
        provider_configuration (list of ProviderConfiguration): The specific
            ProviderConfiguration to be passed to the filtering framework, in
            the form of an array of objects (as JSON).
        uses_cert (bool): Whether the certificate should be attached to this
            profile (one of true, false). False by default

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "provider_configuration":'ProviderConfiguration',
        "app_bundle_identifier":'AppBundleIdentifier',
        "provider_bundle_identifier":'ProviderBundleIdentifier',
        "uses_cert":'usesCert'
    }

    def __init__(self,
                 provider_configuration=None,
                 app_bundle_identifier=None,
                 provider_bundle_identifier=None,
                 uses_cert=None):
        """Constructor for the AddNetworkSmProfileUmbrella class"""

        # Initialize members of the class
        self.app_bundle_identifier = app_bundle_identifier
        self.provider_bundle_identifier = provider_bundle_identifier
        self.provider_configuration = provider_configuration
        self.uses_cert = uses_cert


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        provider_configuration = None
        if dictionary.get('ProviderConfiguration') != None:
            provider_configuration = list()
            for structure in dictionary.get('ProviderConfiguration'):
                provider_configuration.append(test_meraki.models.provider_configuration.ProviderConfiguration.from_dictionary(structure))
        app_bundle_identifier = dictionary.get('AppBundleIdentifier')
        provider_bundle_identifier = dictionary.get('ProviderBundleIdentifier')
        uses_cert = dictionary.get('usesCert')

        # Return an object of this model
        return cls(provider_configuration,
                   app_bundle_identifier,
                   provider_bundle_identifier,
                   uses_cert)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.ap_band_settings
import test_meraki.models.two_four_ghz_settings
import test_meraki.models.five_ghz_settings

class CreateNetworkWirelessRfProfile(object):

    """Implementation of the 'createNetworkWirelessRfProfile' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the new profile. Must be unique. This param
            is required on creation.
        client_balancing_enabled (bool): Steers client to best available
            access point. Can be either true or false. Defaults to true.
        min_bitrate_type (MinBitrateTypeEnum): Minimum bitrate can be set to
            either 'band' or 'ssid'. Defaults to band.
        band_selection_type (BandSelectionTypeEnum): Band selection can be set
            to either 'ssid' or 'ap'. This param is required on creation.
        ap_band_settings (ApBandSettings): Settings that will be enabled if
            selectionType is set to 'ap'.
        two_four_ghz_settings (TwoFourGhzSettings): Settings related to 2.4Ghz
            band
        five_ghz_settings (FiveGhzSettings): Settings related to 5Ghz band

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "band_selection_type":'bandSelectionType',
        "client_balancing_enabled":'clientBalancingEnabled',
        "min_bitrate_type":'minBitrateType',
        "ap_band_settings":'apBandSettings',
        "two_four_ghz_settings":'twoFourGhzSettings',
        "five_ghz_settings":'fiveGhzSettings'
    }

    def __init__(self,
                 name=None,
                 band_selection_type=None,
                 client_balancing_enabled=None,
                 min_bitrate_type=None,
                 ap_band_settings=None,
                 two_four_ghz_settings=None,
                 five_ghz_settings=None):
        """Constructor for the CreateNetworkWirelessRfProfile class"""

        # Initialize members of the class
        self.name = name
        self.client_balancing_enabled = client_balancing_enabled
        self.min_bitrate_type = min_bitrate_type
        self.band_selection_type = band_selection_type
        self.ap_band_settings = ap_band_settings
        self.two_four_ghz_settings = two_four_ghz_settings
        self.five_ghz_settings = five_ghz_settings


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        band_selection_type = dictionary.get('bandSelectionType')
        client_balancing_enabled = dictionary.get('clientBalancingEnabled')
        min_bitrate_type = dictionary.get('minBitrateType')
        ap_band_settings = test_meraki.models.ap_band_settings.ApBandSettings.from_dictionary(dictionary.get('apBandSettings')) if dictionary.get('apBandSettings') else None
        two_four_ghz_settings = test_meraki.models.two_four_ghz_settings.TwoFourGhzSettings.from_dictionary(dictionary.get('twoFourGhzSettings')) if dictionary.get('twoFourGhzSettings') else None
        five_ghz_settings = test_meraki.models.five_ghz_settings.FiveGhzSettings.from_dictionary(dictionary.get('fiveGhzSettings')) if dictionary.get('fiveGhzSettings') else None

        # Return an object of this model
        return cls(name,
                   band_selection_type,
                   client_balancing_enabled,
                   min_bitrate_type,
                   ap_band_settings,
                   two_four_ghz_settings,
                   five_ghz_settings)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.ipsec_policies

class Peer(object):

    """Implementation of the 'Peer' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the VPN peer
        public_ip (string): The public IP of the VPN peer
        remote_id (string): [optional] The remote ID is used to identify the
            connecting VPN peer. This can either be a valid IPv4 Address, FQDN
            or User FQDN.
        private_subnets (list of string): The list of the private subnets of
            the VPN peer
        ipsec_policies (IpsecPolicies): Custom IPSec policies for the VPN
            peer. If not included and a preset has not been chosen, the
            default preset for IPSec policies will be used.
        ipsec_policies_preset (string): One of the following available
            presets: 'default', 'aws', 'azure'. If this is provided, the
            'ipsecPolicies' parameter is ignored.
        secret (string): The shared secret with the VPN peer
        network_tags (list of string): A list of network tags that will
            connect with this peer. Use ['all'] for all networks. Use ['none']
            for no networks. If not included, the default is ['all'].

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "public_ip":'publicIp',
        "private_subnets":'privateSubnets',
        "secret":'secret',
        "remote_id":'remoteId',
        "ipsec_policies":'ipsecPolicies',
        "ipsec_policies_preset":'ipsecPoliciesPreset',
        "network_tags":'networkTags'
    }

    def __init__(self,
                 name=None,
                 public_ip=None,
                 private_subnets=None,
                 secret=None,
                 remote_id=None,
                 ipsec_policies=None,
                 ipsec_policies_preset=None,
                 network_tags=None):
        """Constructor for the Peer class"""

        # Initialize members of the class
        self.name = name
        self.public_ip = public_ip
        self.remote_id = remote_id
        self.private_subnets = private_subnets
        self.ipsec_policies = ipsec_policies
        self.ipsec_policies_preset = ipsec_policies_preset
        self.secret = secret
        self.network_tags = network_tags


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        public_ip = dictionary.get('publicIp')
        private_subnets = dictionary.get('privateSubnets')
        secret = dictionary.get('secret')
        remote_id = dictionary.get('remoteId')
        ipsec_policies = test_meraki.models.ipsec_policies.IpsecPolicies.from_dictionary(dictionary.get('ipsecPolicies')) if dictionary.get('ipsecPolicies') else None
        ipsec_policies_preset = dictionary.get('ipsecPoliciesPreset')
        network_tags = dictionary.get('networkTags')

        # Return an object of this model
        return cls(name,
                   public_ip,
                   private_subnets,
                   secret,
                   remote_id,
                   ipsec_policies,
                   ipsec_policies_preset,
                   network_tags)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.center_1
import test_meraki.models.bottom_left_corner
import test_meraki.models.bottom_right_corner
import test_meraki.models.top_left_corner
import test_meraki.models.top_right_corner

class UpdateNetworkFloorPlan(object):

    """Implementation of the 'updateNetworkFloorPlan' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of your floor plan.
        center (Center1): The longitude and latitude of the center of your
            floor plan. If you want to change the geolocation data of your
            floor plan, either the 'center' or two adjacent corners (e.g.
            'topLeftCorner' and 'bottomLeftCorner') must be specified. If
            'center' is specified, the floor plan is placed over that point
            with no rotation. If two adjacent corners are specified, the floor
            plan is rotated to line up with the two specified points. The
            aspect ratio of the floor plan's image is preserved regardless of
            which corners/center are specified. (This means if that more than
            two corners are specified, only two corners may be used to
            preserve the floor plan's aspect ratio.). No two points can have
            the same latitude, longitude pair.
        bottom_left_corner (BottomLeftCorner): The longitude and latitude of
            the bottom left corner of your floor plan.
        bottom_right_corner (BottomRightCorner): The longitude and latitude of
            the bottom right corner of your floor plan.
        top_left_corner (TopLeftCorner): The longitude and latitude of the top
            left corner of your floor plan.
        top_right_corner (TopRightCorner): The longitude and latitude of the
            top right corner of your floor plan.
        image_contents (string): The file contents (a base 64 encoded string)
            of your new image. Supported formats are PNG, GIF, and JPG. Note
            that all images are saved as PNG files, regardless of the format
            they are uploaded in. If you upload a new image, and you do NOT
            specify any new geolocation fields ('center, 'topLeftCorner',
            etc), the floor plan will be recentered with no rotation in order
            to maintain the aspect ratio of your new image.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "center":'center',
        "bottom_left_corner":'bottomLeftCorner',
        "bottom_right_corner":'bottomRightCorner',
        "top_left_corner":'topLeftCorner',
        "top_right_corner":'topRightCorner',
        "image_contents":'imageContents'
    }

    def __init__(self,
                 name=None,
                 center=None,
                 bottom_left_corner=None,
                 bottom_right_corner=None,
                 top_left_corner=None,
                 top_right_corner=None,
                 image_contents=None):
        """Constructor for the UpdateNetworkFloorPlan class"""

        # Initialize members of the class
        self.name = name
        self.center = center
        self.bottom_left_corner = bottom_left_corner
        self.bottom_right_corner = bottom_right_corner
        self.top_left_corner = top_left_corner
        self.top_right_corner = top_right_corner
        self.image_contents = image_contents


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        center = test_meraki.models.center_1.Center1.from_dictionary(dictionary.get('center')) if dictionary.get('center') else None
        bottom_left_corner = test_meraki.models.bottom_left_corner.BottomLeftCorner.from_dictionary(dictionary.get('bottomLeftCorner')) if dictionary.get('bottomLeftCorner') else None
        bottom_right_corner = test_meraki.models.bottom_right_corner.BottomRightCorner.from_dictionary(dictionary.get('bottomRightCorner')) if dictionary.get('bottomRightCorner') else None
        top_left_corner = test_meraki.models.top_left_corner.TopLeftCorner.from_dictionary(dictionary.get('topLeftCorner')) if dictionary.get('topLeftCorner') else None
        top_right_corner = test_meraki.models.top_right_corner.TopRightCorner.from_dictionary(dictionary.get('topRightCorner')) if dictionary.get('topRightCorner') else None
        image_contents = dictionary.get('imageContents')

        # Return an object of this model
        return cls(name,
                   center,
                   bottom_left_corner,
                   bottom_right_corner,
                   top_left_corner,
                   top_right_corner,
                   image_contents)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class AuthModeEnum(object):

    """Implementation of the 'AuthMode' enum.

    The association control method for the SSID ('open', 'psk',
    'open-with-radius', '8021x-meraki' or '8021x-radius')

    Attributes:
        OPEN: TODO: type description here.
        PSK: TODO: type description here.
        OPENWITHRADIUS: TODO: type description here.
        ENUM_8021XMERAKI: TODO: type description here.
        ENUM_8021XRADIUS: TODO: type description here.

    """

    OPEN = 'open'

    PSK = 'psk'

    OPENWITHRADIUS = 'open-with-radius'

    ENUM_8021XMERAKI = '8021x-meraki'

    ENUM_8021XRADIUS = '8021x-radius'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.tag
import test_meraki.models.network

class CreateOrganizationAdmin(object):

    """Implementation of the 'createOrganizationAdmin' model.

    TODO: type model description here.

    Attributes:
        email (string): The email of the dashboard administrator. This
            attribute can not be updated.
        name (string): The name of the dashboard administrator
        org_access (OrgAccessEnum): The privilege of the dashboard
            administrator on the organization. Can be one of 'full',
            'read-only', 'enterprise' or 'none'
        tags (list of Tag): The list of tags that the dashboard administrator
            has privileges on
        networks (list of Network): The list of networks that the dashboard
            administrator has privileges on

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "email":'email',
        "name":'name',
        "org_access":'orgAccess',
        "tags":'tags',
        "networks":'networks'
    }

    def __init__(self,
                 email=None,
                 name=None,
                 org_access=None,
                 tags=None,
                 networks=None):
        """Constructor for the CreateOrganizationAdmin class"""

        # Initialize members of the class
        self.email = email
        self.name = name
        self.org_access = org_access
        self.tags = tags
        self.networks = networks


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        email = dictionary.get('email')
        name = dictionary.get('name')
        org_access = dictionary.get('orgAccess')
        tags = None
        if dictionary.get('tags') != None:
            tags = list()
            for structure in dictionary.get('tags'):
                tags.append(test_meraki.models.tag.Tag.from_dictionary(structure))
        networks = None
        if dictionary.get('networks') != None:
            networks = list()
            for structure in dictionary.get('networks'):
                networks.append(test_meraki.models.network.Network.from_dictionary(structure))

        # Return an object of this model
        return cls(email,
                   name,
                   org_access,
                   tags,
                   networks)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class License(object):

    """Implementation of the 'License' model.

    TODO: type model description here.

    Attributes:
        key (string): The key of the license
        mode (Mode2Enum): Either 'renew' or 'addDevices'. 'addDevices' will
            increase the license limit, while 'renew' will extend the amount
            of time until expiration. This parameter is legacy and only
            applies to coterm licensing; it should not be specified when
            claiming per-device licenses. Please see <a target='_blank'
            href='https://documentation.meraki.com/zGeneral_Administration/Lice
            nsing/Adding_an_Enterprise_license_to_an_existing_Dashboard_account
            '>this article</a> for more information.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'key',
        "mode":'mode'
    }

    def __init__(self,
                 key=None,
                 mode=None):
        """Constructor for the License class"""

        # Initialize members of the class
        self.key = key
        self.mode = mode


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('key')
        mode = dictionary.get('mode')

        # Return an object of this model
        return cls(key,
                   mode)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class ProviderConfiguration(object):

    """Implementation of the 'ProviderConfiguration' model.

    TODO: type model description here.

    Attributes:
        key (string): The key for an object in ProviderConfiguration
        mtype (string): The type for an object in ProviderConfiguration. Can
            be one of 'manual_string', 'manual_int', 'manual_boolean',
            'manual_choice', 'manual_multiselect', 'manual_list',
            'auto_username', 'auto_email', 'auto_mac_address',
            'auto_serial_number', 'auto_notes' or 'auto_name'
        value (string): The value for an object in ProviderConfiguration

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key":'key',
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 key=None,
                 mtype=None,
                 value=None):
        """Constructor for the ProviderConfiguration class"""

        # Initialize members of the class
        self.key = key
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = dictionary.get('key')
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(key,
                   mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DhcpLeaseTimeEnum(object):

    """Implementation of the 'DhcpLeaseTime' enum.

    The term of DHCP leases if the appliance is running a DHCP server on this
    VLAN. One of: '30 minutes', '1 hour', '4 hours', '12 hours', '1 day' or '1
    week'

    Attributes:
        ENUM_30 MINUTES: TODO: type description here.
        ENUM_1 HOUR: TODO: type description here.
        ENUM_4 HOURS: TODO: type description here.
        ENUM_12 HOURS: TODO: type description here.
        ENUM_1 DAY: TODO: type description here.
        ENUM_1 WEEK: TODO: type description here.

    """

    ENUM_30_MINUTES = '30 minutes'

    ENUM_1_HOUR = '1 hour'

    ENUM_4_HOURS = '4 hours'

    ENUM_12_HOURS = '12 hours'

    ENUM_1_DAY = '1 day'

    ENUM_1_WEEK = '1 week'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Network(object):

    """Implementation of the 'Network' model.

    TODO: type model description here.

    Attributes:
        id (string): The network ID
        access (string): The privilege of the dashboard administrator on the
            network

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id":'id',
        "access":'access'
    }

    def __init__(self,
                 id=None,
                 access=None):
        """Constructor for the Network class"""

        # Initialize members of the class
        self.id = id
        self.access = access


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        access = dictionary.get('access')

        # Return an object of this model
        return cls(id,
                   access)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class StpBridgePriority(object):

    """Implementation of the 'StpBridgePriority' model.

    TODO: type model description here.

    Attributes:
        switch_profiles (list of string): List of switch profile IDs
        switches (list of string): List of switch serial numbers
        stacks (list of string): List of stack IDs
        stp_priority (int): STP priority for switch, stacks, or switch
            profiles

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "stp_priority":'stpPriority',
        "switch_profiles":'switchProfiles',
        "switches":'switches',
        "stacks":'stacks'
    }

    def __init__(self,
                 stp_priority=None,
                 switch_profiles=None,
                 switches=None,
                 stacks=None):
        """Constructor for the StpBridgePriority class"""

        # Initialize members of the class
        self.switch_profiles = switch_profiles
        self.switches = switches
        self.stacks = stacks
        self.stp_priority = stp_priority


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        stp_priority = dictionary.get('stpPriority')
        switch_profiles = dictionary.get('switchProfiles')
        switches = dictionary.get('switches')
        stacks = dictionary.get('stacks')

        # Return an object of this model
        return cls(stp_priority,
                   switch_profiles,
                   switches,
                   stacks)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class ClientsController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_device_clients(self,
                           serial,
                           t_0=None,
                           timespan=None):
        """Does a GET request to /devices/{serial}/clients.

        List the clients of a device, up to a maximum of a month ago. The
        usage of each client is returned in kilobytes. If the device is a
        switch, the switchport is returned; otherwise the switchport field is
        null.

        Args:
            serial (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 31 days from today.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameter t0. The value must be in seconds and be less than or
                equal to 31 days. The default is 1 day.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/devices/{serial}/clients'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'serial': serial
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            'timespan': timespan
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_clients(self,
                            network_id,
                            t_0=None,
                            timespan=None,
                            per_page=None,
                            starting_after=None,
                            ending_before=None):
        """Does a GET request to /networks/{networkId}/clients.

        List the clients that have used this network in the timespan

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 31 days from today.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameter t0. The value must be in seconds and be less than or
                equal to 31 days. The default is 1 day.
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000. Default is 10.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            'timespan': timespan,
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_provision_network_clients(self,
                                         network_id,
                                         provision_network_clients=None):
        """Does a POST request to /networks/{networkId}/clients/provision.

        Provisions a client with a name and policy. Clients can be provisioned
        before they associate to the network.

        Args:
            network_id (string): TODO: type description here. Example: 
            provision_network_clients (ProvisionNetworkClients, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/provision'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(provision_network_clients))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client(self,
                           network_id,
                           client_id):
        """Does a GET request to /networks/{networkId}/clients/{clientId}.

        Return the client associated with the given identifier. Clients can be
        identified by a client key or either the MAC or IP depending on
        whether the network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_events(self,
                                  network_id,
                                  client_id,
                                  per_page=None,
                                  starting_after=None,
                                  ending_before=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/events.

        Return the events associated with this client. Clients can be
        identified by a client key or either the MAC or IP depending on
        whether the network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 100. Default is 100.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/events'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_latency_history(self,
                                           network_id,
                                           client_id,
                                           t_0=None,
                                           t_1=None,
                                           timespan=None,
                                           resolution=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/latencyHistory.

        Return the latency history for a client. Clients can be identified by
        a client key or either the MAC or IP depending on whether the network
        uses Track-by-IP. The latency data is from a sample of 2% of packets
        and is grouped into 4 traffic categories: background, best effort,
        video, voice. Within these categories the sampled packet counters are
        bucketed by latency in milliseconds.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 791 days from today.
            t_1 (string, optional): The end of the timespan for the data. t1
                can be a maximum of 791 days after t0.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameters t0 and t1. The value must be in seconds and be less
                than or equal to 791 days. The default is 1 day.
            resolution (int, optional): The time resolution in seconds for
                returned data. The valid resolutions are: 86400. The default
                is 86400.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/latencyHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            't1': t_1,
            'timespan': timespan,
            'resolution': resolution
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_policy(self,
                                  network_id,
                                  client_id):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/policy.

        Return the policy assigned to a client on the network. Clients can be
        identified by a client key or either the MAC or IP depending on
        whether the network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/policy'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_client_policy(self,
                                     network_id,
                                     client_id,
                                     update_network_client_policy=None):
        """Does a PUT request to /networks/{networkId}/clients/{clientId}/policy.

        Update the policy assigned to a client on the network. Clients can be
        identified by a client key or either the MAC or IP depending on
        whether the network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            update_network_client_policy (UpdateNetworkClientPolicy,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/policy'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_client_policy))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_splash_authorization_status(self,
                                                       network_id,
                                                       client_id):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/splashAuthorizationStatus.

        Return the splash authorization for a client, for each SSID they've
        associated with through splash. Only enabled SSIDs with Click-through
        splash enabled will be included. Clients can be identified by a client
        key or either the MAC or IP depending on whether the network uses
        Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/splashAuthorizationStatus'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_client_splash_authorization_status(self,
                                                          network_id,
                                                          client_id,
                                                          update_network_client_splash_authorization_status=None):
        """Does a PUT request to /networks/{networkId}/clients/{clientId}/splashAuthorizationStatus.

        Update a client's splash authorization. Clients can be identified by a
        client key or either the MAC or IP depending on whether the network
        uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            update_network_client_splash_authorization_status
                (UpdateNetworkClientSplashAuthorizationStatus, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/splashAuthorizationStatus'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_client_splash_authorization_status))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_traffic_history(self,
                                           network_id,
                                           client_id,
                                           per_page=None,
                                           starting_after=None,
                                           ending_before=None):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/trafficHistory.

        Return the client's network traffic data over time. Usage data is in
        kilobytes. This endpoint requires detailed traffic analysis to be
        enabled on the Network-wide > General page. Clients can be identified
        by a client key or either the MAC or IP depending on whether the
        network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 
            per_page (int, optional): The number of entries per page returned.
                Acceptable range is 3 - 1000.
            starting_after (string, optional): A token used by the server to
                indicate the start of the page. Often this is a timestamp or
                an ID but it is not limited to those. This parameter should
                not be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.
            ending_before (string, optional): A token used by the server to
                indicate the end of the page. Often this is a timestamp or an
                ID but it is not limited to those. This parameter should not
                be defined by client applications. The link for the first,
                last, prev, or next page in the HTTP Link header should define
                it.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/trafficHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'perPage': per_page,
            'startingAfter': starting_after,
            'endingBefore': ending_before
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_client_usage_history(self,
                                         network_id,
                                         client_id):
        """Does a GET request to /networks/{networkId}/clients/{clientId}/usageHistory.

        Return the client's daily usage history. Usage data is in kilobytes.
        Clients can be identified by a client key or either the MAC or IP
        depending on whether the network uses Track-by-IP.

        Args:
            network_id (string): TODO: type description here. Example: 
            client_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/clients/{clientId}/usageHistory'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'clientId': client_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class Access1Enum(object):

    """Implementation of the 'Access1' enum.

    The type of SNMP access. Can be one of 'none' (disabled), 'community'
    (V1/V2c), or 'users' (V3).

    Attributes:
        NONE: TODO: type description here.
        COMMUNITY: TODO: type description here.
        USERS: TODO: type description here.

    """

    NONE = 'none'

    COMMUNITY = 'community'

    USERS = 'users'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class DefaultDestinations(object):

    """Implementation of the 'DefaultDestinations' model.

    The network_wide destinations for all alerts on the network.

    Attributes:
        emails (list of string): A list of emails that will recieve the
            alert(s).
        all_admins (bool): If true, then all network admins will receive
            emails.
        snmp (bool): If true, then an SNMP trap will be sent if there is an
            SNMP trap server configured for this network.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "emails":'emails',
        "all_admins":'allAdmins',
        "snmp":'snmp'
    }

    def __init__(self,
                 emails=None,
                 all_admins=None,
                 snmp=None):
        """Constructor for the DefaultDestinations class"""

        # Initialize members of the class
        self.emails = emails
        self.all_admins = all_admins
        self.snmp = snmp


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        emails = dictionary.get('emails')
        all_admins = dictionary.get('allAdmins')
        snmp = dictionary.get('snmp')

        # Return an object of this model
        return cls(emails,
                   all_admins,
                   snmp)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class NamedTagScopeController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_sm_target_groups(self,
                                     network_id,
                                     with_details=None):
        """Does a GET request to /networks/{networkId}/sm/targetGroups.

        List the target groups in this network

        Args:
            network_id (string): TODO: type description here. Example: 
            with_details (bool, optional): Boolean indicating if the the ids
                of the devices or users scoped by the target group should be
                included in the response

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/targetGroups'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'withDetails': with_details
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_sm_target_group(self,
                                       network_id,
                                       create_network_sm_target_group=None):
        """Does a POST request to /networks/{networkId}/sm/targetGroups.

        Add a target group

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_sm_target_group (CreateNetworkSmTargetGroup,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/targetGroups'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_sm_target_group))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_sm_target_group(self,
                                    network_id,
                                    target_group_id,
                                    with_details=None):
        """Does a GET request to /networks/{networkId}/sm/targetGroups/{targetGroupId}.

        Return a target group

        Args:
            network_id (string): TODO: type description here. Example: 
            target_group_id (string): TODO: type description here. Example: 
            with_details (bool, optional): Boolean indicating if the the ids
                of the devices or users scoped by the target group should be
                included in the response

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/targetGroups/{targetGroupId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'targetGroupId': target_group_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'withDetails': with_details
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_sm_target_group(self,
                                       network_id,
                                       target_group_id,
                                       update_network_sm_target_group=None):
        """Does a PUT request to /networks/{networkId}/sm/targetGroups/{targetGroupId}.

        Update a target group

        Args:
            network_id (string): TODO: type description here. Example: 
            target_group_id (string): TODO: type description here. Example: 
            update_network_sm_target_group (UpdateNetworkSmTargetGroup,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/targetGroups/{targetGroupId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'targetGroupId': target_group_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_sm_target_group))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_sm_target_group(self,
                                       network_id,
                                       target_group_id):
        """Does a DELETE request to /networks/{networkId}/sm/targetGroups/{targetGroupId}.

        Delete a target group from a network

        Args:
            network_id (string): TODO: type description here. Example: 
            target_group_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/sm/targetGroups/{targetGroupId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'targetGroupId': target_group_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)
